@@ -103,6 +103,9 @@
       integer MPI_MODE_DELETE_ON_CLOSE, MPI_MODE_UNIQUE_OPEN
       integer MPI_MODE_EXCL, MPI_MODE_APPEND, MPI_MODE_SEQUENTIAL
       integer MPI_DISPLACEMENT_CURRENT
+      integer MPI_MODE_NOCHECK, MPI_MODE_NOPRECEDE, MPI_MODE_NOPUT
+      integer MPI_MODE_NOSTORE, MPI_MODE_NOSUCCEED
+      integer MPI_LOCK_EXCLUSIVE, MPI_LOCK_SHARED
       integer MPI_WIN_BASE, MPI_WIN_SIZE, MPI_WIN_DISP_UNIT
       
       parameter (MPI_ANY_SOURCE=-1)
@@ -111,7 +114,7 @@
       parameter (MPI_ROOT=-4)
       parameter (MPI_MAX_PROCESSOR_NAME=255)
       parameter (MPI_MAX_ERROR_STRING=255)
-      parameter (MPI_MAX_DATAREP_STRING=128)
+      parameter (MPI_MAX_DATAREP_STRING=127)
       parameter (MPI_UNDEFINED=-32766)
       parameter (MPI_CART=1)
       parameter (MPI_GRAPH=2)
@@ -161,6 +164,14 @@
       parameter (MPI_MODE_APPEND=128)
       parameter (MPI_MODE_SEQUENTIAL=256)
       parameter (MPI_DISPLACEMENT_CURRENT=-54278278)
+      parameter (MPI_MODE_NOCHECK=1)
+      parameter (MPI_MODE_NOPRECEDE=2)
+      parameter (MPI_MODE_NOPUT=4)
+      parameter (MPI_MODE_NOSTORE=8)
+      parameter (MPI_MODE_NOSUCCEED=16)
+      parameter (MPI_LOCK_EXCLUSIVE=1)
+      parameter (MPI_LOCK_SHARED=2)
+
 !     
 !     MPI sentinel values
 !
@@ -213,7 +224,7 @@
 !     
       integer MPI_GROUP_NULL, MPI_COMM_NULL, MPI_DATATYPE_NULL
       integer MPI_REQUEST_NULL, MPI_OP_NULL, MPI_ERRHANDLER_NULL
-      integer MPI_INFO_NULL, MPI_WIN_NULL
+      integer MPI_INFO_NULL, MPI_WIN_NULL, MPI_FILE_NULL
       
       parameter (MPI_GROUP_NULL=0)
       parameter (MPI_COMM_NULL=2)
@@ -223,6 +234,7 @@
       parameter (MPI_ERRHANDLER_NULL=0)
       parameter (MPI_INFO_NULL=0)
       parameter (MPI_WIN_NULL=0)
+      parameter (MPI_FILE_NULL=0)
 !     
 !     MPI_Init_thread constants
 !     
@@ -423,6 +435,7 @@
       integer MPI_COMPLEX, MPI_COMPLEX8, MPI_COMPLEX16, MPI_COMPLEX32
       integer MPI_DOUBLE_COMPLEX
       integer MPI_2REAL, MPI_2DOUBLE_PRECISION, MPI_2INTEGER
+      integer MPI_2COMPLEX, MPI_2DOUBLE_COMPLEX
       
       parameter (MPI_BYTE=1)
       parameter (MPI_PACKED=2)
@@ -449,6 +462,8 @@
       parameter (MPI_2REAL=23)
       parameter (MPI_2DOUBLE_PRECISION=24)
       parameter (MPI_2INTEGER=25)
+      parameter (MPI_2COMPLEX=26)
+      parameter (MPI_2DOUBLE_COMPLEX=27)
       
       integer MPI_MAX, MPI_MIN, MPI_SUM, MPI_PROD, MPI_LAND
       integer MPI_BAND, MPI_LOR, MPI_BOR, MPI_LXOR, MPI_BXOR
